@@ -5,6 +5,7 @@ import requests
 from requests import cookies
 import json
 import hashlib
+from typing import Dict, Union
 
 from ThermiaOnlineAPI.const import (
     REG_GROUP_HOT_WATER,
@@ -12,6 +13,9 @@ from ThermiaOnlineAPI.const import (
     REG_GROUP_OPERATIONAL_STATUS,
     REG_GROUP_OPERATIONAL_TIME,
     REG_GROUP_TEMPERATURES,
+    REG_HOT_WATER_STATUS,
+    REG__HOT_WATER_BOOST,
+    REG_OPERATIONMODE,
     THERMIA_API_CONFIG_URLS_BY_API_TYPE,
     THERMIA_AZURE_AUTH_URL,
     THERMIA_AZURE_AUTH_CLIENT_ID_AND_SCOPE,
@@ -27,6 +31,19 @@ from ..utils import utils
 
 _LOGGER = logging.getLogger(__name__)
 
+# Azure auth URLs
+AZURE_AUTH_AUTHORIZE_URL = THERMIA_AZURE_AUTH_URL + "/oauth2/v2.0/authorize"
+AZURE_AUTH_GET_TOKEN_URL = THERMIA_AZURE_AUTH_URL + "/oauth2/v2.0/token"
+AZURE_SELF_ASSERTED_URL = THERMIA_AZURE_AUTH_URL + "/SelfAsserted"
+AZURE_AUTH_CONFIRM_URL = (
+    THERMIA_AZURE_AUTH_URL + "/api/CombinedSigninAndSignup/confirmed"
+)
+
+# Azure default headers
+azure_auth_request_headers = {
+    "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8"
+}
+
 
 class ThermiaAPI:
     def __init__(self, email, password, api_type):
@@ -202,7 +219,7 @@ class ThermiaAPI:
             device.id, REG_GROUP_OPERATIONAL_OPERATION
         )
 
-        data = [d for d in register_data if d["registerName"] == "REG_OPERATIONMODE"]
+        data = [d for d in register_data if d["registerName"] == REG_OPERATIONMODE]
 
         if len(data) != 1:
             # Operation mode not supported
@@ -244,26 +261,68 @@ class ThermiaAPI:
 
         return None
 
-    def get_group_hot_water(self, device: ThermiaHeatPump):
-        register_data = self.__get_register_group(device.id, REG_GROUP_HOT_WATER)
+    def __get_switch_register_index_and_value_from_group_by_register_name(
+        self, register_group: list, register_name: str
+    ):
+        default_return_object = {
+            "registerIndex": None,
+            "registerValue": None,
+        }
 
-        data = [d for d in register_data if d["registerName"] == "REG_HOT_WATER_STATUS"]
+        switch_data_list = [
+            d for d in register_group if d["registerName"] == register_name
+        ]
 
-        if len(data) == 0:
-            # Hot water switch not supported
-            return None
+        if len(switch_data_list) != 1:
+            # Switch not supported
+            return default_return_object
 
-        data = data[0]
+        switch_data: dict = switch_data_list[0]
 
-        device.set_register_index_hot_water_switch(data["registerIndex"])
+        register_value = switch_data.get("registerValue")
 
-        current_switch_state = int(data.get("registerValue"))
-        switch_states_data = data.get("valueNames")
+        if register_value is None:
+            return default_return_object
 
-        if switch_states_data is not None and len(switch_states_data) == 2:
-            return current_switch_state
+        # Validate that register is a switch
+        switch_states_data = switch_data.get("valueNames")
 
-        return None
+        if switch_states_data is None or len(switch_states_data) != 2:
+            return default_return_object
+
+        return {
+            "registerIndex": switch_data["registerIndex"],
+            "registerValue": int(register_value),
+        }
+
+    def get_group_hot_water(
+        self, device: ThermiaHeatPump
+    ) -> Dict[str, Union[int, None]]:
+        register_data: list = self.__get_register_group(device.id, REG_GROUP_HOT_WATER)
+
+        hot_water_switch_data = (
+            self.__get_switch_register_index_and_value_from_group_by_register_name(
+                register_data, REG_HOT_WATER_STATUS
+            )
+        )
+        hot_water_boost_switch_data = (
+            self.__get_switch_register_index_and_value_from_group_by_register_name(
+                register_data, REG__HOT_WATER_BOOST
+            )
+        )
+
+        device.set_register_index_hot_water_switch(
+            hot_water_switch_data["registerIndex"]
+        )
+
+        device.set_register_index_hot_water_boost_switch(
+            hot_water_boost_switch_data["registerIndex"]
+        )
+
+        return {
+            "hot_water_switch": hot_water_switch_data["registerValue"],
+            "hot_water_boost_switch": hot_water_boost_switch_data["registerValue"],
+        }
 
     def set_temperature(self, device: ThermiaHeatPump, temperature):
         device_temperature_register_index = device.get_register_indexes()["temperature"]
@@ -312,18 +371,26 @@ class ThermiaAPI:
     def set_hot_water_switch_state(
         self, device: ThermiaHeatPump, state: int
     ):  # 0 - off, 1 - on
-        device_hot_water_switch_state_register_index = device.get_register_indexes()[
-            "hot_water_switch"
-        ]
-        if device_hot_water_switch_state_register_index is None:
+        register_index = device.get_register_indexes()["hot_water_switch"]
+        if register_index is None:
             _LOGGER.error(
                 "Error setting device's hot water switch state. No hot water switch register index."
             )
             return
 
-        self.__set_register_value(
-            device, device_hot_water_switch_state_register_index, state
-        )
+        self.__set_register_value(device, register_index, state)
+
+    def set_hot_water_boost_switch_state(
+        self, device: ThermiaHeatPump, state: int
+    ):  # 0 - off, 1 - on
+        register_index = device.get_register_indexes()["hot_water_boost_switch"]
+        if register_index is None:
+            _LOGGER.error(
+                "Error setting device's hot water boost switch state. No hot water boost switch register index."
+            )
+            return
+
+        self.__set_register_value(device, register_index, state)
 
     def get_register_group_json(self, device_id: str, register_group: str) -> list:
         return self.__get_register_group(device_id, register_group)
@@ -395,49 +462,44 @@ class ThermiaAPI:
 
         return request.json()
 
-    def __authenticate(self) -> bool:
-        # Azure auth URLs
-        azure_auth_authorize_url = THERMIA_AZURE_AUTH_URL + "/oauth2/v2.0/authorize"
-        azure_auth_get_token_url = THERMIA_AZURE_AUTH_URL + "/oauth2/v2.0/token"
-        azure_self_asserted_url = THERMIA_AZURE_AUTH_URL + "/SelfAsserted"
-        azure_auth_confirm_url = (
-            THERMIA_AZURE_AUTH_URL + "/api/CombinedSigninAndSignup/confirmed"
-        )
-
-        # Azure default headers
-        azure_auth_request_headers = {
-            "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8"
+    def __authenticate_refresh_token(self) -> Union[str, None]:
+        request_token__data = {
+            "client_id": THERMIA_AZURE_AUTH_CLIENT_ID_AND_SCOPE,
+            "redirect_uri": THERMIA_AZURE_AUTH_REDIRECT_URI,
+            "scope": THERMIA_AZURE_AUTH_CLIENT_ID_AND_SCOPE,
+            "refresh_token": self.__refresh_token,
+            "grant_type": "refresh_token",
         }
 
+        request_token = requests.post(
+            AZURE_AUTH_GET_TOKEN_URL,
+            headers=azure_auth_request_headers,
+            data=request_token__data,
+        )
+
+        if request_token.status_code != 200:
+            error_text = (
+                "Reauthentication request failed with previous refresh token. Status: "
+                + str(request_token.status_code)
+                + ", Response: "
+                + request_token.text
+            )
+            _LOGGER.error(error_text)
+            return None
+
+        return request_token.text
+
+    def __authenticate(self) -> bool:
         refresh_azure_token = self.__refresh_token_valid_to and (
             self.__refresh_token_valid_to > datetime.now().timestamp()
         )
 
+        request_token_text = None
+
         if refresh_azure_token:  # Refresh token
-            request_token__data = {
-                "client_id": THERMIA_AZURE_AUTH_CLIENT_ID_AND_SCOPE,
-                "redirect_uri": THERMIA_AZURE_AUTH_REDIRECT_URI,
-                "scope": THERMIA_AZURE_AUTH_CLIENT_ID_AND_SCOPE,
-                "refresh_token": self.__refresh_token,
-                "grant_type": "refresh_token",
-            }
+            request_token_text = self.__authenticate_refresh_token()
 
-            request_token = requests.post(
-                azure_auth_get_token_url,
-                headers=azure_auth_request_headers,
-                data=request_token__data,
-            )
-
-            if request_token.status_code != 200:
-                error_text = (
-                    "Reauthentication request failed with previous refresh token. Status: "
-                    + str(request_token.status_code)
-                    + ", Response: "
-                    + request_token.text
-                )
-                _LOGGER.error(error_text)
-                raise AuthenticationException(error_text)
-        else:
+        if request_token_text is None:  # New token, or refresh failed
             code_challenge = utils.generate_challenge(43)
 
             request_auth__data = {
@@ -454,7 +516,7 @@ class ThermiaAPI:
                 "code_challenge_method": "S256",
             }
 
-            request_auth = requests.get(azure_auth_authorize_url, request_auth__data)
+            request_auth = requests.get(AZURE_AUTH_AUTHORIZE_URL, request_auth__data)
 
             state_code = ""
             csrf_token = ""
@@ -490,7 +552,7 @@ class ThermiaAPI:
             }
 
             request_self_asserted = requests.post(
-                azure_self_asserted_url,
+                AZURE_SELF_ASSERTED_URL,
                 cookies=request_auth.cookies,
                 data=request_self_asserted__data,
                 headers={**azure_auth_request_headers, "X-Csrf-Token": csrf_token},
@@ -523,7 +585,7 @@ class ThermiaAPI:
             }
 
             request_confirmed = requests.get(
-                azure_auth_confirm_url,
+                AZURE_AUTH_CONFIRM_URL,
                 cookies=request_confirmed__cookies,
                 params=request_confirmed__params,
             )
@@ -538,7 +600,7 @@ class ThermiaAPI:
             }
 
             request_token = requests.post(
-                azure_auth_get_token_url,
+                AZURE_AUTH_GET_TOKEN_URL,
                 headers=azure_auth_request_headers,
                 data=request_token__data,
             )
@@ -553,7 +615,9 @@ class ThermiaAPI:
                 _LOGGER.error(error_text)
                 raise AuthenticationException(error_text)
 
-        token_data = json.loads(request_token.text)
+            request_token_text = request_token.text
+
+        token_data = json.loads(request_token_text)
 
         self.__token = token_data["access_token"]
         self.__token_valid_to = token_data["expires_on"]
